@@ -4,11 +4,11 @@ use warnings;
 use utf8;
 use WWW::MobileCarrierJP::Declare;
 
-my $url = 'http://creation.mb.softbank.jp/terminal/?lup=y&cat=http';
+my $url = 'http://creation.mb.softbank.jp/mc/terminal/terminal_info/terminal_httphedder.html';
 
 parse_one(
     urls  => [$url],
-    xpath => '//div/table/tr/td/table[@bordercolor="#999999"]/tr[not(@bgcolor="#ee9abb") and not(@bgcolor="#cccccc") and count(child::td) = 7]',
+    xpath => '//div[@class="terminaltable"]/table/tr[not(position()=1)]',
     scraper => scraper {
         process 'td:nth-child(1)', 'model', 'TEXT';
 
